# Import Cage and Linker objects as well as an autode EST object for xtb
from cgbind import Linker, Cage, xtb

# Inform user about the available architectures
print("Available architectures: ['m4l6', 'm2l4', 'm4l6n', 'm6l8', 'm12l24', 'm4l6t']")

# Ask user for input, if no input is given, use default values
smiles = input("Enter SMILES string or press enter to use default ('C1(C#CC2=CC=CC(C#CC3=CC=CN=C3)=C2)=CC=CN=C1'): ") or 'C1(C#CC2=CC=CC(C#CC3=CC=CN=C3)=C2)=CC=CN=C1'
arch_name = input("Enter one of the available architectures or press enter to use default ('m2l4'): ") or 'm2l4'
metal = input("Enter metal or press enter to use default ('Pd'): ") or 'Pd'
metal_charge = input("Enter metal charge or press enter to use default ('2'): ") or '2'

# Generates the linker
linker = Linker(name='linker_opt',
                smiles=smiles,
                arch_name=arch_name)

# From the optimsied linker build the M2L4 cage with Pd(II) ions
cage = Cage(linker, metal=metal, metal_charge=metal_charge)

# Optimise the cage with XTB using 4 cores.
cage.optimise(method=xtb, n_cores=4)

cage.print_xyz_file()

# Convert xyz to gjf
def convert_xyz_to_gjf(input_file, output_file):
    with open(input_file, 'r') as f:
        lines = f.readlines()

    atoms = lines[2:]

    with open(output_file, 'w') as f:
        f.write('#p B3LYP/6-31G(d) opt\n\n')
        f.write('created from cage_linker_opt.xyz' + '\n\n')
        f.write('0' + ' 1\n')
        for atom in atoms:
            f.write(atom)

convert_xyz_to_gjf('cage_linker_opt.xyz', 'cage_linker_opt.gjf')

print("metallocage generated successfully")